@@ -25,6 +25,7 @@ import re
 import sys
 import os.path
 import shutil
+from datetime import datetime
 from copy import deepcopy
 from datetime import datetime
 from robot.libraries.BuiltIn import BuiltIn
@@ -39,7 +40,7 @@ from ExcelDataDriver.Keywords.CoreExcelKeywords import CoreExcelKeywords
 from ExcelDataDriver.Config.CaptureScreenShotOption import CaptureScreenShotOption
 
 
-__version__ = '1.1.6'
+__version__ = '1.2.1'
 
 
 class ExcelDataDriver:
@@ -69,6 +70,7 @@ class ExcelDataDriver:
         - ``MAXIMUM_ROW``: Maximum test data row. (default is None)
 
         """
+        print(str(datetime.now()) + ': Init RPA ExcelDataDriver Library')
         self.ROBOT_LIBRARY_LISTENER = self
         self.file = file
 
@@ -108,6 +110,7 @@ class ExcelDataDriver:
         return __import__(module_path, fromlist=[module])
 
     def start_suite(self, suite, result):
+        print(str(datetime.now()) + ': start_suite')
         """``Important`` using by local library only."""
         if self.manually_test:
             return
@@ -139,6 +142,8 @@ class ExcelDataDriver:
         suite.tests = temp_test_list
 
     def end_suite(self, name, attributes):
+        print(str(datetime.now()) + ': end_suite')
+
         """``Important`` using by local library only."""
         if self.manually_test:
             return
@@ -186,7 +191,6 @@ class ExcelDataDriver:
         Values are data of this column as array.
         """
         # Load xlsx test data file
-        print('Load excel xlsx test data file')
         self.excelTestDataService.load_test_data(self.file, self.custom_parser)
         offset_row = BuiltIn().get_variable_value('${OFFSET_ROW}', 0)
         maximum_row = BuiltIn().get_variable_value('${MAXIMUM_ROW}', None)
@@ -237,16 +241,13 @@ class ExcelDataDriver:
                                       args=self.template_test.keywords.teardown.args)
 
     def _add_test_case_tags(self, test_data):
-        # print('Set Test case tags')
         for tag in test_data.get_testcase_tags():
             self.test.tags.add(tag)
 
     def _get_template_args(self, test_data):
-        # print('Set Template args')
         return_args = []
         for arg in self.template_keyword.args:
             arg = arg.replace('${', '').replace('}', '')
-            print(arg)
             return_args.append(test_data.get_test_data_property(arg))
         return return_args
 
@@ -265,7 +266,6 @@ class ExcelDataDriver:
     def _capture_screenshot(self):
         try:
             # Capture selenium screenshot
-            custom_selenium = CustomSelenium()
             today = datetime.now()
             date_and_time = today.strftime("%Y%m%d%H%M%S")
             screenshot_name = date_and_time + '_' + str(self.screenshot_running_id) + '.png'
@@ -274,10 +274,24 @@ class ExcelDataDriver:
                 os.makedirs('./' + ExcelDataDriver.REPORT_PATH + '/screenshots/')
             except:
                 None
+
+            # Capture screenshot by selenium
+            is_capture_success = False
             try:
+                custom_selenium = CustomSelenium()
                 custom_selenium.capture_full_page_screenshot('./'+ExcelDataDriver.REPORT_PATH+'/screenshots/'+screenshot_name)
+                is_capture_success = True
             except Exception as e:
-                return str(e)
+                is_capture_success = False
+
+            # Capture screenshot by puppeteer
+            if is_capture_success is False:
+                try:
+                    library = BuiltIn().get_library_instance('PuppeteerLibrary')
+                    library.capture_page_screenshot('./'+ExcelDataDriver.REPORT_PATH+'/screenshots/'+screenshot_name, True)
+                except Exception as e:
+                    return e
+
             return '=HYPERLINK(".//screenshots//' + screenshot_name + '","' + screenshot_name + '")'
         except:
             return None
@@ -523,6 +537,21 @@ class ExcelDataDriver:
         """
         self.excelTestDataService.save_report(newfile)
 
+    ####################################################
+    #
+    # Insert selective columns
+    #
+    ####################################################
+    @keyword
+    def auto_insert_extra_columns(self, filename, main_column_key, columns=[],
+                                  custom_parser_module='ExcelDataDriver.ExcelParser.DefaultReferenceParserStrategy',
+                                  custom_parser_class='DefaultReferenceParserStrategy'):
+        reference_wb = OpenpyxlHelper.load_excel_file(filename)
+        CustomExcelParser = getattr(importlib.import_module(custom_parser_module), custom_parser_class)
+        parser_context = ParserContext(CustomExcelParser(main_column_key))
+        parser_context.insert_extra_columns(reference_wb, columns)
+        reference_wb.save(filename)
+
     ####################################################
     #
     # Load reference excel data
